Contact
=======

For bugs or feature requests, please use the
`GitHub issue tracker <https://github.com/chris-mcdo/django-overcomingbias-api/issues>`_.

For anything else, you can contact me at cmcdonal33 (at) gmail (dot) com.
